
From: Ingo Molnar <mingo@elte.hu>

Introduce proper declarations for i8253_lock and i8259A_lock.

Signed-off-by: Ingo Molnar <mingo@elte.hu>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 arch/i386/kernel/apic.c                  |    2 +-
 arch/i386/kernel/apm.c                   |    5 ++---
 arch/i386/kernel/io_apic.c               |    2 +-
 arch/i386/kernel/time.c                  |    5 ++++-
 arch/i386/kernel/timers/timer_cyclone.c  |    4 ++--
 arch/i386/kernel/timers/timer_pit.c      |    4 +---
 arch/i386/kernel/timers/timer_tsc.c      |    3 +--
 arch/i386/mach-voyager/voyager_basic.c   |    2 +-
 arch/x86_64/kernel/io_apic.c             |    1 -
 drivers/ide/legacy/hd.c                  |    4 +++-
 drivers/input/gameport/gameport.c        |    3 ++-
 drivers/input/joystick/analog.c          |    4 +++-
 include/asm-i386/i8253.h                 |    6 ++++++
 include/asm-i386/mach-default/do_timer.h |    1 +
 include/asm-x86_64/io_apic.h             |    2 ++
 15 files changed, 30 insertions(+), 18 deletions(-)

diff -puN arch/i386/kernel/apic.c~x86-i8253-i8259a-lock-cleanup arch/i386/kernel/apic.c
--- 25/arch/i386/kernel/apic.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/arch/i386/kernel/apic.c	Fri Jun 24 15:32:49 2005
@@ -34,6 +34,7 @@
 #include <asm/desc.h>
 #include <asm/arch_hooks.h>
 #include <asm/hpet.h>
+#include <asm/i8253.h>
 
 #include <mach_apic.h>
 
@@ -857,7 +858,6 @@ fake_ioapic_page:
  */
 static unsigned int __init get_8254_timer_count(void)
 {
-	extern spinlock_t i8253_lock;
 	unsigned long flags;
 
 	unsigned int count;
diff -puN arch/i386/kernel/apm.c~x86-i8253-i8259a-lock-cleanup arch/i386/kernel/apm.c
--- 25/arch/i386/kernel/apm.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/arch/i386/kernel/apm.c	Fri Jun 24 15:32:49 2005
@@ -228,10 +228,10 @@
 #include <asm/system.h>
 #include <asm/uaccess.h>
 #include <asm/desc.h>
+#include <asm/i8253.h>
 
 #include "io_ports.h"
 
-extern spinlock_t i8253_lock;
 extern unsigned long get_cmos_time(void);
 extern void machine_real_restart(unsigned char *, int);
 
@@ -1168,8 +1168,7 @@ static void get_time_diff(void)
 static void reinit_timer(void)
 {
 #ifdef INIT_TIMER_AFTER_SUSPEND
-	unsigned long	flags;
-	extern spinlock_t i8253_lock;
+	unsigned long flags;
 
 	spin_lock_irqsave(&i8253_lock, flags);
 	/* set the clock to 100 Hz */
diff -puN arch/i386/kernel/io_apic.c~x86-i8253-i8259a-lock-cleanup arch/i386/kernel/io_apic.c
--- 25/arch/i386/kernel/io_apic.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/arch/i386/kernel/io_apic.c	Fri Jun 24 15:32:49 2005
@@ -37,6 +37,7 @@
 #include <asm/smp.h>
 #include <asm/desc.h>
 #include <asm/timer.h>
+#include <asm/i8259.h>
 
 #include <mach_apic.h>
 
@@ -1566,7 +1567,6 @@ void print_all_local_APICs (void)
 
 void /*__init*/ print_PIC(void)
 {
-	extern spinlock_t i8259A_lock;
 	unsigned int v;
 	unsigned long flags;
 
diff -puN arch/i386/kernel/time.c~x86-i8253-i8259a-lock-cleanup arch/i386/kernel/time.c
--- 25/arch/i386/kernel/time.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/arch/i386/kernel/time.c	Fri Jun 24 15:32:49 2005
@@ -68,7 +68,8 @@
 
 #include "io_ports.h"
 
-extern spinlock_t i8259A_lock;
+#include <asm/i8259.h>
+
 int pit_latch_buggy;              /* extern */
 
 #include "do_timer.h"
@@ -85,6 +86,8 @@ extern unsigned long wall_jiffies;
 DEFINE_SPINLOCK(rtc_lock);
 EXPORT_SYMBOL(rtc_lock);
 
+#include <asm/i8253.h>
+
 DEFINE_SPINLOCK(i8253_lock);
 EXPORT_SYMBOL(i8253_lock);
 
diff -puN arch/i386/kernel/timers/timer_cyclone.c~x86-i8253-i8259a-lock-cleanup arch/i386/kernel/timers/timer_cyclone.c
--- 25/arch/i386/kernel/timers/timer_cyclone.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/arch/i386/kernel/timers/timer_cyclone.c	Fri Jun 24 15:32:49 2005
@@ -17,9 +17,9 @@
 #include <asm/io.h>
 #include <asm/pgtable.h>
 #include <asm/fixmap.h>
-#include "io_ports.h"
+#include <asm/i8253.h>
 
-extern spinlock_t i8253_lock;
+#include "io_ports.h"
 
 /* Number of usecs that the last interrupt was delayed */
 static int delay_at_last_interrupt;
diff -puN arch/i386/kernel/timers/timer_pit.c~x86-i8253-i8259a-lock-cleanup arch/i386/kernel/timers/timer_pit.c
--- 25/arch/i386/kernel/timers/timer_pit.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/arch/i386/kernel/timers/timer_pit.c	Fri Jun 24 15:32:49 2005
@@ -15,9 +15,8 @@
 #include <asm/smp.h>
 #include <asm/io.h>
 #include <asm/arch_hooks.h>
+#include <asm/i8253.h>
 
-extern spinlock_t i8259A_lock;
-extern spinlock_t i8253_lock;
 #include "do_timer.h"
 #include "io_ports.h"
 
@@ -166,7 +165,6 @@ struct init_timer_opts __initdata timer_
 
 void setup_pit_timer(void)
 {
-	extern spinlock_t i8253_lock;
 	unsigned long flags;
 
 	spin_lock_irqsave(&i8253_lock, flags);
diff -puN arch/i386/kernel/timers/timer_tsc.c~x86-i8253-i8259a-lock-cleanup arch/i386/kernel/timers/timer_tsc.c
--- 25/arch/i386/kernel/timers/timer_tsc.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/arch/i386/kernel/timers/timer_tsc.c	Fri Jun 24 15:32:49 2005
@@ -24,6 +24,7 @@
 #include "mach_timer.h"
 
 #include <asm/hpet.h>
+#include <asm/i8253.h>
 
 #ifdef CONFIG_HPET_TIMER
 static unsigned long hpet_usec_quotient;
@@ -35,8 +36,6 @@ static inline void cpufreq_delayed_get(v
 
 int tsc_disable __initdata = 0;
 
-extern spinlock_t i8253_lock;
-
 static int use_tsc;
 /* Number of usecs that the last interrupt was delayed */
 static int delay_at_last_interrupt;
diff -puN arch/i386/mach-voyager/voyager_basic.c~x86-i8253-i8259a-lock-cleanup arch/i386/mach-voyager/voyager_basic.c
--- 25/arch/i386/mach-voyager/voyager_basic.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/arch/i386/mach-voyager/voyager_basic.c	Fri Jun 24 15:32:49 2005
@@ -30,6 +30,7 @@
 #include <linux/irq.h>
 #include <asm/tlbflush.h>
 #include <asm/arch_hooks.h>
+#include <asm/i8253.h>
 
 /*
  * Power off function, if any
@@ -182,7 +183,6 @@ voyager_timer_interrupt(struct pt_regs *
 		 * and swiftly introduce it to something sharp and
 		 * pointy.  */
 		__u16 val;
-		extern spinlock_t i8253_lock;
 
 		spin_lock(&i8253_lock);
 		
diff -puN arch/x86_64/kernel/io_apic.c~x86-i8253-i8259a-lock-cleanup arch/x86_64/kernel/io_apic.c
--- 25/arch/x86_64/kernel/io_apic.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/arch/x86_64/kernel/io_apic.c	Fri Jun 24 15:32:49 2005
@@ -1064,7 +1064,6 @@ void print_all_local_APICs (void)
 
 void __apicdebuginit print_PIC(void)
 {
-	extern spinlock_t i8259A_lock;
 	unsigned int v;
 	unsigned long flags;
 
diff -puN drivers/ide/legacy/hd.c~x86-i8253-i8259a-lock-cleanup drivers/ide/legacy/hd.c
--- 25/drivers/ide/legacy/hd.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/drivers/ide/legacy/hd.c	Fri Jun 24 15:32:49 2005
@@ -156,11 +156,13 @@ else \
 
 
 #if (HD_DELAY > 0)
+
+#include <asm/i8253.h>
+
 unsigned long last_req;
 
 unsigned long read_timer(void)
 {
-        extern spinlock_t i8253_lock;
 	unsigned long t, flags;
 	int i;
 
diff -puN drivers/input/gameport/gameport.c~x86-i8253-i8259a-lock-cleanup drivers/input/gameport/gameport.c
--- 25/drivers/input/gameport/gameport.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/drivers/input/gameport/gameport.c	Fri Jun 24 15:32:49 2005
@@ -60,12 +60,13 @@ static void gameport_disconnect_port(str
 
 #if defined(__i386__)
 
+#include <asm/i8253.h>
+
 #define DELTA(x,y)      ((y)-(x)+((y)<(x)?1193182/HZ:0))
 #define GET_TIME(x)     do { x = get_time_pit(); } while (0)
 
 static unsigned int get_time_pit(void)
 {
-	extern spinlock_t i8253_lock;
 	unsigned long flags;
 	unsigned int count;
 
diff -puN drivers/input/joystick/analog.c~x86-i8253-i8259a-lock-cleanup drivers/input/joystick/analog.c
--- 25/drivers/input/joystick/analog.c~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/drivers/input/joystick/analog.c	Fri Jun 24 15:32:49 2005
@@ -140,12 +140,14 @@ struct analog_port {
  */
 
 #ifdef __i386__
+
+#include <asm/i8253.h>
+
 #define GET_TIME(x)	do { if (cpu_has_tsc) rdtscl(x); else x = get_time_pit(); } while (0)
 #define DELTA(x,y)	(cpu_has_tsc ? ((y) - (x)) : ((x) - (y) + ((x) < (y) ? CLOCK_TICK_RATE / HZ : 0)))
 #define TIME_NAME	(cpu_has_tsc?"TSC":"PIT")
 static unsigned int get_time_pit(void)
 {
-        extern spinlock_t i8253_lock;
         unsigned long flags;
         unsigned int count;
 
diff -puN /dev/null include/asm-i386/i8253.h
--- /dev/null	Thu Apr 11 07:25:15 2002
+++ 25-akpm/include/asm-i386/i8253.h	Fri Jun 24 15:32:49 2005
@@ -0,0 +1,6 @@
+#ifndef __ASM_I8253_H__
+#define __ASM_I8253_H__
+
+extern spinlock_t i8253_lock;
+
+#endif	/* __ASM_I8253_H__ */
diff -puN include/asm-i386/mach-default/do_timer.h~x86-i8253-i8259a-lock-cleanup include/asm-i386/mach-default/do_timer.h
--- 25/include/asm-i386/mach-default/do_timer.h~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/include/asm-i386/mach-default/do_timer.h	Fri Jun 24 15:32:49 2005
@@ -1,6 +1,7 @@
 /* defines for inline arch setup functions */
 
 #include <asm/apic.h>
+#include <asm/i8259.h>
 
 /**
  * do_timer_interrupt_hook - hook into timer tick
diff -puN include/asm-x86_64/io_apic.h~x86-i8253-i8259a-lock-cleanup include/asm-x86_64/io_apic.h
--- 25/include/asm-x86_64/io_apic.h~x86-i8253-i8259a-lock-cleanup	Fri Jun 24 15:32:49 2005
+++ 25-akpm/include/asm-x86_64/io_apic.h	Fri Jun 24 15:32:49 2005
@@ -217,4 +217,6 @@ extern int assign_irq_vector(int irq);
 
 void enable_NMI_through_LVT0 (void * dummy);
 
+extern spinlock_t i8259A_lock;
+
 #endif
_
